@@ -1,12 +1,13 @@
 # -*- encoding: utf-8; indent-tabs-mode: nil -*-
 #
 #     Perl Date::Convert extension to convert dates from/to the French Revolutionary calendar
-#     Copyright (C) 2001-2003, 2013 Jean Forget
+#     Copyright (C) 2001-2003, 2013, 2015 Jean Forget
 #
 #     See the license in the embedded documentation below.
 #
 package Date::Convert::French_Rev;
 
+use utf8;
 use strict;
 use warnings;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
@@ -21,7 +22,7 @@ require Exporter;
 @EXPORT = qw(
         
 );
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 use constant REV_BEGINNING => 2375840; # 1 Vendémiaire I in the Revolutionary calendar
 my @MONTHS_SHORT  = qw ( Vnd Bru Fri Niv Plu Vnt Ger Flo Pra Mes The Fru S-C);
@@ -172,6 +173,12 @@ use constant FOUR_MILLENIA  => 10 * FOUR_CENTURIES - 1; # ...except every four m
 my @YEARS_BEGINS=    (0, 365, 730, 1096, 1461, 1826, 2191, 2557, 2922, 3287, 3652,
                    4018, 4383, 4748, 5113, 5479, 5844);
 
+# This method shoudl be in the master class, but for the moment, it is only available here
+sub change_to {
+  my ($self, $new_cal) = @_;
+  $new_cal->convert($self);
+}
+
 sub initialize {
     my $self = shift;
     my ($year, $month, $day) = @_;
@@ -331,7 +338,7 @@ sub field {
       my $jj = 30 * $self->month + $self->day - 31; # %j is 1..366, but $jj is 0..365
       my $lb = $DAYS[$jj];
       $lb =~ s/_/ /g;
-      $lb =~ s/^(\d)/$PREFIXES[$1 % 4]/;
+      $lb =~ s/^(\d)/$PREFIXES[$1]/;
       return $lb;
     };
   $spec eq '%EJ'  && do
@@ -340,7 +347,7 @@ sub field {
       my $lb = $DAYS[$jj];
       $lb =~ s/_/ /g;
       # Using a capitalized prefix, and capitalizing the first letter
-      $lb =~ s/^(\d)(.)/\u$PREFIXES[$1 % 4]\u$2/;
+      $lb =~ s/^(\d)(.)/\u$PREFIXES[$1]\u$2/;
       return $lb;
     };
   $spec eq '%Oj'  && do
@@ -405,6 +412,11 @@ Converting from Revolutionary to Gregorian (or other)
 
     $date = Date::Convert::French_Rev->new(8, 2, 18);   # 18 Brumaire VIII...
     Date::Convert::Gregorian->convert($date);
+
+Alternate way of converting from Revolutionary to Gregorian (or other)
+
+    $date = Date::Convert::French_Rev->new(8, 2, 18);   # 18 Brumaire VIII...
+    $date->change_to("Date::Convert::Gregorian");
     print $date->date_string, "\n";                     # ... is "1799 Nov 9"
 
 =head1 REQUIRES
@@ -591,25 +603,24 @@ be "1" or greater.
 
 =item month %s out of range
 
-The  French Revolutionary  calendar has  12 months,  plus 5  or 6
-additional  days that  do not  belong to  a month.  So  the month
-number  must be  in the  1-12 range  for normal  days, or  13 for
-additional days
+The  French  Revolutionary  calendar  has  12  months,  plus  5  or  6
+additional days  that do not belong  to a month.  So  the month number
+must be in the 1-12 range for normal days, or 13 for additional days
+
+=item standard day number %s out of range
+
+The day number for any normal month is in the 1-30 range.
 
 =item additional day %s out of range
 
-The day number for the end-of-year additional days is a number in
-the 1-5 range (or the 1-6 range for leap years).
+The day number for the end-of-year  additional days is a number in the
+1-5 range (or the 1-6 range for leap years).
 
 =item Date::Convert::French_Rev::initialize needs more args
 
 You  must provide  a year,  a month  number and  a day  number to
 C<Date::Convert::French_Rev::initialize>.
 
-=item standard day number %s out of range
-
-The day number for any normal month is in the 1-30 range.
-
 =back
 
 =head1 KNOWN BUGS AND CAVEATS
@@ -631,6 +642,11 @@ I  have checked the  manpage for  C<date(1)> in  two flavors  of Unix:
 Linux and AIX. In the best case, the extended field descriptors C<%Ex>
 and C<%Oy> are poorly documented, but usually they are not documented.
 
+The C<Test::Exception>  module is required for the  build process, not
+for  the   regular  use  of   C<Date::Convert::French_Rev>.  But  with
+C<ExtUtils::MakeMaker>,   I   do   not   know  how   to   generate   a
+C<build_requires> entry in F<META.yml>.
+
 =head1 HISTORICAL NOTES
 
 The Revolutionary calendar was in  use in France from 24 November 1793
@@ -651,33 +667,18 @@ leap year rule similar to the Gregorian calendar rule.
 In his book  I<The French Revolution>, the 19th  century writer Thomas
 Carlyle proposes these translations for the month names:
 
-=over 4
-
-=item Vendémiaire -> Vintagearious
-
-=item Brumaire -> Fogarious
-
-=item Frimaire -> Frostarious
-
-=item Nivôse -> Snowous
-
-=item Pluviôse -> Rainous
-
-=item Ventôse -> Windous
-
-=item Germinal -> Buddal
-
-=item Floréal -> Floweral
-
-=item Prairial -> Meadowal
-
-=item Messidor -> Reapidor
-
-=item Thermidor -> Heatidor
-
-=item Fructidor -> Fruitidor
-
-=back
+  Vendémiaire -> Vintagearious
+  Brumaire    -> Fogarious
+  Frimaire    -> Frostarious
+  Nivôse      -> Snowous
+  Pluviôse    -> Rainous
+  Ventôse     -> Windous
+  Germinal    -> Buddal
+  Floréal     -> Floweral
+  Prairial    -> Meadowal
+  Messidor    -> Reapidor
+  Thermidor   -> Heatidor
+  Fructidor   -> Fruitidor
 
 =head1 AUTHOR
 
@@ -689,11 +690,11 @@ based on Mordechai T. Abzug's work <morty@umbc.edu>
 
 =head2 Software
 
-date(1), perl(1), Date::DateCalc(3), Date::Convert(3)
+date(1), perl(1), L<Date::Convert>
 
 calendar/cal-french.el in emacs or xemacs
 
-DateTime and DateTime::Calendar::FrenchRevolutionary
+L<DateTime> and L<DateTime::Calendar::FrenchRevolutionary>
 
 =head2 books
 
@@ -707,18 +708,18 @@ The French Revolution, Thomas Carlyle, Oxford University Press
 
 =head2 Internet
 
-http://www.faqs.org/faqs/calendars/faq/part3/
+L<http://www.faqs.org/faqs/calendars/faq/part3/>
 
-http://h2g2.com/approved_entry/A2903636
+L<http://h2g2.com/approved_entry/A2903636>
 
-http://en.wikipedia.org/wiki/French_Republican_Calendar
+L<http://en.wikipedia.org/wiki/French_Republican_Calendar>
 
-http://prairial.free.fr/calendrier/calendrier.php?lien=sommairefr
+L<http://prairial.free.fr/calendrier/calendrier.php?lien=sommairefr>
 (in French)
 
 =head1 LICENSE
 
-Copyright  (c)  2001,  2002,  2003,  2013  Jean  Forget.   All  rights
+Copyright (c)  2001, 2002, 2003,  2013, 2015 Jean Forget.   All rights
 reserved.  This program is free software.  You can distribute, modify,
 and otherwise mangle Date::Convert::French_Rev under the same terms as
 Perl 5.16.3: GNU  Public License version 1 or  later and Perl Artistic
